{
	"name" : "Network Management",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Enterprise Specific Modules/Information Technology",
	"depends" : ["base"],
	"init_xml" : [],
	"description": "A simple module to encode your networks and materials. Interventions, waranties, software installed, logins, ...",
	"demo_xml" : ["network_demo.xml"],
	"update_xml" : ["network_view.xml", "network_report.xml"],
	"active" : False,
	"installable": True
}
